@@ -24,7 +24,7 @@
 
 #define MAXSTRING 256  /* Maximum input string allowed */
 
-#define HEADER_STRING "GNU Unifont 10.0.05" /* to be printed as chart title */
+#define HEADER_STRING "GNU Unifont 10.0.06" /* to be printed as chart title */
 
 /*
      Define the array of Unifont ASCII glyphs, code points 0 through 127.
@@ -80,10 +80,10 @@ const char *ascii_hex [128] = {
    "002C:00000000000000000000000018080810",
    "002D:0000000000000000003C000000000000",
    "002E:00000000000000000000000018180000",
-   "002F:00000000020204080810.0.050400000",
+   "002F:00000000020204080810102040400000",
    "0030:00000000182442464A52624224180000",
    "0031:000000000818280808080808083E0000",
-   "0032:000000003C4242020C10.0.0507E0000",
+   "0032:000000003C4242020C102040407E0000",
    "0033:000000003C4242021C020242423C0000",
    "0034:00000000040C142444447E0404040000",
    "0035:000000007E4040407C020202423C0000",
@@ -123,7 +123,7 @@ const char *ascii_hex [128] = {
    "0057:00000000424242425A5A666642420000",
    "0058:00000000424224241818242442420000",
    "0059:00000000414122221408080808080000",
-   "005A:000000007E0202040810.0.0507E0000",
+   "005A:000000007E02020408102040407E0000",
    "005B:0000000E080808080808080808080E00",
    "005C:00000000404020101008080402020000",
    "005D:00000070101010101010101010107000",
